@@ -1,3 +1,4 @@
+import atexit
 import logging
 import os
 from subprocess import Popen  # , PIPE, STDOUT
@@ -18,13 +19,14 @@ def read_dotenv(filename):
     -------
     dict
 
-    Raises
-    ------
-    FileNotFoundError
-
     """
-    with open(filename, 'r') as fh:
-        data = fh.read()
+    try:
+        with open(filename, 'r') as fh:
+            data = fh.read()
+    except FileNotFoundError:
+        logger.warning(f"{filename} does not exist, continuing without "
+                       "setting environment variables.")
+        data = ""
 
     res = {}
     for line in data.splitlines():
@@ -64,7 +66,24 @@ def read_dotenv(filename):
 
 
 def run_dotenv(filename, command):
+    """Run dotenv.
 
+    This function executes the commands with the environment variables
+    parsed from filename.
+
+    Parameters
+    ----------
+    filename : str
+        path to the .env file
+    command : list[str]
+        command to execute
+
+    Returns
+    -------
+    int
+        the return value
+
+    """
     # read dotenv
     dotenv = read_dotenv(filename)
 
@@ -83,5 +102,24 @@ def run_dotenv(filename, command):
         shell=False,
         env=env,
     )
+
+    def terminate_proc():
+        """Kill child process.
+
+        All signals should be forwarded to the child processes
+        automatically, however child processes are also free to ignore
+        some of them. With this we make sure the child processes get
+        killed once dotenv exits.
+
+        """
+        proc.kill()
+
+    # register
+    atexit.register(terminate_proc)
+
     _, _ = proc.communicate()
+
+    # unregister
+    atexit.unregister(terminate_proc)
+
     return proc.returncode
