@@ -4,6 +4,7 @@ import tempfile
 
 import pytest
 
+
 DOTENV_FILE = """
 # comment=foo
 TEST=foo
@@ -43,9 +44,8 @@ def test_returncode(dotenvfile):
 
 
 def test_alternative_dotenv():
-    f = tempfile.NamedTemporaryFile('w')
-    with open(f.name, 'w') as fh:
-        fh.write('foo=bar')
+    with tempfile.NamedTemporaryFile('w', delete=False) as f:
+        f.write('foo=bar')
 
     proc = run(['dotenv', '-e', f.name, 'env'], stdout=PIPE)
     assert b'foo=bar' in proc.stdout
@@ -55,10 +55,9 @@ def test_alternative_dotenv():
 
 
 def test_nonexisting_dotenv():
-
     proc = run(['dotenv', '-e', '/tmp/i.dont.exist', 'true'], stderr=PIPE)
-    assert proc.returncode != 0
-    assert b'FileNotFoundError' in proc.stderr
+    assert proc.returncode == 0
+    assert b'does not exist' in proc.stderr
 
 
 def test_no_command():
