@@ -6,7 +6,6 @@ from dotenv_cli import core
 
 
 def test_full():
-    f = tempfile.NamedTemporaryFile('w')
     TEST = r"""
 BASIC=basic basic
 export EXPORT=foo
@@ -22,8 +21,8 @@ MULTILINE_NQ=multi\nline
 should be ignored
 """
 
-    with open(f.name, 'w') as fh:
-        fh.write(TEST)
+    with tempfile.NamedTemporaryFile('w', delete=False) as f:
+        f.write(TEST)
 
     env = core.read_dotenv(f.name)
     assert env['BASIC'] == 'basic basic'
@@ -42,11 +41,10 @@ should be ignored
 
 def test_basic():
     """Basic unquoted strings"""
-    f = tempfile.NamedTemporaryFile('w')
     TEST = "FOO=BAR"
 
-    with open(f.name, 'w') as fh:
-        fh.write(TEST)
+    with tempfile.NamedTemporaryFile('w', delete=False) as f:
+        f.write(TEST)
 
     env = core.read_dotenv(f.name)
     assert env['FOO'] == 'BAR'
@@ -54,11 +52,10 @@ def test_basic():
 
 def test_empty():
     """Empty values become empty strings."""
-    f = tempfile.NamedTemporaryFile('w')
     TEST = "FOO="
 
-    with open(f.name, 'w') as fh:
-        fh.write(TEST)
+    with tempfile.NamedTemporaryFile('w', delete=False) as f:
+        f.write(TEST)
 
     env = core.read_dotenv(f.name)
     assert env['FOO'] == ''
@@ -66,31 +63,23 @@ def test_empty():
 
 def test_inner_quotes():
     """Inner quotes are mainained."""
-    f = tempfile.NamedTemporaryFile('w')
-    TEST = "FOO=this 'is' a test"
+    TEST = "\n".join(["FOO1=this 'is' a test",
+                      'FOO2=this "is" a test'])
 
-    with open(f.name, 'w') as fh:
-        fh.write(TEST)
+    with tempfile.NamedTemporaryFile('w', delete=False) as f:
+        f.write(TEST)
 
     env = core.read_dotenv(f.name)
-    assert env['FOO'] == "this 'is' a test"
-
-    TEST = 'FOO=this "is" a test'
-
-    with open(f.name, 'w') as fh:
-        fh.write(TEST)
-
-    env = core.read_dotenv(f.name)
-    assert env['FOO'] == 'this "is" a test'
+    assert env['FOO1'] == "this 'is' a test"
+    assert env['FOO2'] == 'this "is" a test'
 
 
 def test_trim_whitespaces():
     """Whitespaces are stripped from unquoted values."""
-    f = tempfile.NamedTemporaryFile('w')
     TEST = "FOO=  test  "
 
-    with open(f.name, 'w') as fh:
-        fh.write(TEST)
+    with tempfile.NamedTemporaryFile('w', delete=False) as f:
+        f.write(TEST)
 
     env = core.read_dotenv(f.name)
     assert env['FOO'] == "test"
@@ -98,11 +87,10 @@ def test_trim_whitespaces():
 
 def test_keep_whitespaces():
     """Whitespaces are mainteined from quoted values."""
-    f = tempfile.NamedTemporaryFile('w')
     TEST = "FOO='  test  '"
 
-    with open(f.name, 'w') as fh:
-        fh.write(TEST)
+    with tempfile.NamedTemporaryFile('w', delete=False) as f:
+        f.write(TEST)
 
     env = core.read_dotenv(f.name)
     assert env['FOO'] == "  test  "
@@ -110,11 +98,10 @@ def test_keep_whitespaces():
 
 def test_multiline():
     """Quoted values can contain newlines."""
-    f = tempfile.NamedTemporaryFile('w')
     TEST = r'FOO="This is\nbar"'
 
-    with open(f.name, 'w') as fh:
-        fh.write(TEST)
+    with tempfile.NamedTemporaryFile('w', delete=False) as f:
+        f.write(TEST)
 
     env = core.read_dotenv(f.name)
     assert env['FOO'] == 'This is\nbar'
@@ -127,10 +114,8 @@ def test_multiline():
     ('FOO="\'Test\'"', "'Test'"),
 ])
 def test_quotes(input_, expected):
-    f = tempfile.NamedTemporaryFile('w')
-
-    with open(f.name, 'w') as fh:
-        fh.write(input_)
+    with tempfile.NamedTemporaryFile('w', delete=False) as f:
+        f.write(input_)
 
     env = core.read_dotenv(f.name)
     assert env['FOO'] == expected
@@ -138,16 +123,14 @@ def test_quotes(input_, expected):
 
 def test_comments():
     """Lines starting with # are ignored."""
-    f = tempfile.NamedTemporaryFile('w')
-
     TEST = """
     FOO=BAR
     # comment
     BAR=BAZ
     """
 
-    with open(f.name, 'w') as fh:
-        fh.write(TEST)
+    with tempfile.NamedTemporaryFile('w', delete=False) as f:
+        f.write(TEST)
 
     env = core.read_dotenv(f.name)
     assert len(env) == 2
@@ -157,16 +140,14 @@ def test_comments():
 
 def test_emtpy_lines():
     """Empty lines are skipped."""
-    f = tempfile.NamedTemporaryFile('w')
-
     TEST = """
     FOO=BAR
 
     BAR=BAZ
     """
 
-    with open(f.name, 'w') as fh:
-        fh.write(TEST)
+    with tempfile.NamedTemporaryFile('w', delete=False) as f:
+        f.write(TEST)
 
     env = core.read_dotenv(f.name)
     assert len(env) == 2
@@ -176,12 +157,10 @@ def test_emtpy_lines():
 
 def test_export():
     """Exports are allowed."""
-    f = tempfile.NamedTemporaryFile('w')
-
     TEST = "export FOO=BAR"
 
-    with open(f.name, 'w') as fh:
-        fh.write(TEST)
+    with tempfile.NamedTemporaryFile('w', delete=False) as f:
+        f.write(TEST)
 
     env = core.read_dotenv(f.name)
     assert env['FOO'] == 'BAR'
